import { MultiscaleSpatialImage, ensure3dDirection, } from './MultiscaleSpatialImage.js';
import { CXYZT, chunk, orderBy, toDimensionMap } from './dimensionUtils.js';
class Coords {
    constructor(image, dims) {
        this.coords = new Map();
        let spatialDimIndex = 0;
        if (dims[0] == 'c') {
            spatialDimIndex = 1;
            const coord = new Float32Array(image.imageType.components);
            for (let c = 0; c < image.imageType.components; c++) {
                coord[c] = c;
            }
            this.coords.set('c', coord);
        }
        let spatialIndex = 0;
        for (let d = spatialDimIndex; d < dims.length; d++) {
            const size = image.size[spatialIndex];
            const origin = image.origin[spatialIndex];
            const spacing = image.spacing[spatialIndex];
            const coord = new Float32Array(size);
            for (let i = 0; i < size; i++) {
                coord[i] = origin + i * spacing;
            }
            this.coords.set(dims[d], coord);
            spatialIndex++;
        }
    }
    async get(coord) {
        return this.coords.get(coord);
    }
    has(coord) {
        return this.coords.has(coord);
    }
}
const imageToScaleInfo = (image) => {
    const imageType = image.imageType;
    const dims = ['y', 'x'];
    const sizeCXYZTElements = [
        imageType.components,
        image.size[0],
        image.size[1],
        1,
        1,
    ];
    if (imageType.components > 1) {
        dims.push('c');
    }
    if (imageType.dimension == 3) {
        dims.unshift('z');
        sizeCXYZTElements[3] = image.size[2];
    }
    const sizeCXYZTChunks = [...sizeCXYZTElements];
    const orderByDims = orderBy(dims);
    const direction3d = ensure3dDirection(image.direction);
    const numberOfCXYZTChunks = [1, 1, 1, 1, 1];
    const scaleInfo = {
        dims,
        coords: new Coords(image, [...dims].reverse()), // Coords assumes xyz
        chunkCount: orderByDims(toDimensionMap(CXYZT, numberOfCXYZTChunks)),
        chunkSize: orderByDims(toDimensionMap(CXYZT, sizeCXYZTChunks)),
        arrayShape: orderByDims(toDimensionMap(CXYZT, sizeCXYZTElements)),
        direction: chunk(3, [...direction3d].reverse()), // reverse to cast xyz to zyx
    };
    return scaleInfo;
};
export class ItkWasmMultiscaleSpatialImage extends MultiscaleSpatialImage {
    constructor(image) {
        const scaleInfos = [imageToScaleInfo(image)];
        super(scaleInfos, image.imageType);
        this.image = image;
    }
    async getChunksImpl(
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    _scale, 
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    _cxyztArray) {
        if (!this.image.data) {
            throw new Error('Image data is null');
        }
        return [this.image.data?.buffer];
    }
}
//# sourceMappingURL=ItkWasmMultiscaleSpatialImage.js.map