import { mat3, ReadonlyMat3, ReadonlyMat4 } from 'gl-matrix';
import { ImageType } from 'itk-wasm';
import { Bounds, ReadonlyBounds } from '@itk-viewer/utils/bounding-box.js';
import { Dimension, ReadOnlyDimensionBounds, ScaleInfo, SpatialDimensions, TypedArrayConstructor } from './types.js';
type ReadonlyFloatArray = Readonly<Float32Array> | Readonly<Float64Array> | ReadonlyMat3;
export declare const ensure3dDirection: (maybe2dDirection: ReadonlyFloatArray) => mat3;
export declare const worldBoundsToIndexBounds: ({ bounds, fullIndexBounds, worldToIndex, }: {
    bounds: ReadonlyBounds | undefined;
    fullIndexBounds: ReadOnlyDimensionBounds;
    worldToIndex: ReadonlyMat4;
}) => Map<Dimension, import("./types.js").ReadonlyRange>;
type ImageCache = Map<number, Array<{
    bounds: ReadOnlyDimensionBounds;
    image: ImageWithMeta;
}>>;
export declare class MultiscaleSpatialImage {
    scaleInfos: Array<ScaleInfo>;
    name: string;
    imageType: ImageType;
    pixelArrayType: TypedArrayConstructor;
    spatialDims: SpatialDimensions;
    cachedImages: ImageCache;
    constructor(scaleInfos: Array<ScaleInfo>, imageType: ImageType, name?: string);
    get coarsestScale(): number;
    scaleOrigin(scale: number): Promise<number[]>;
    scaleSpacing(scale: number): Promise<number[]>;
    get direction(): Float64Array;
    protected getChunks(scale: number, cxyztArray: Array<Array<number>>): Promise<ArrayBuffer[]>;
    protected getChunksImpl(_scale: number, _cxyztArray: Array<Array<number>>): Promise<Array<ArrayBuffer>>;
    buildImage(scale: number, indexBounds: ReadOnlyDimensionBounds): Promise<{
        imageType: ImageType;
        name: string;
        origin: number[];
        spacing: number[];
        direction: Float64Array;
        size: number[];
        data: ArrayBuffer;
        ranges: import("./types.js").Ranges | number[][] | undefined;
        metadata: Map<any, any>;
    }>;
    scaleIndexToWorld(requestedScale: number): Promise<ReadonlyMat4>;
    buildAndCacheImage(scale: number, indexBounds: Bounds): Promise<{
        imageType: ImageType;
        name: string;
        origin: number[];
        spacing: number[];
        direction: Float64Array;
        size: number[];
        data: ArrayBuffer;
        ranges: import("./types.js").Ranges | number[][] | undefined;
        metadata: Map<any, any>;
    }>;
    getImage(requestedScale: number, worldBounds?: ReadonlyBounds | undefined): Promise<{
        imageType: ImageType;
        name: string;
        origin: number[];
        spacing: number[];
        direction: Float64Array;
        size: number[];
        data: ArrayBuffer;
        ranges: import("./types.js").Ranges | number[][] | undefined;
        metadata: Map<any, any>;
    }>;
    getImageInImageSpace(scale: number, normalizedImageBounds?: ReadonlyBounds): Promise<{
        imageType: ImageType;
        name: string;
        origin: number[];
        spacing: number[];
        direction: Float64Array;
        size: number[];
        data: ArrayBuffer;
        ranges: import("./types.js").Ranges | number[][] | undefined;
        metadata: Map<any, any>;
    }>;
    getIndexBounds(scale: number): Map<Dimension, readonly [0, number]>;
    getIndexExtent(scale: number): Bounds;
    getWorldBounds(scale: number): Promise<Bounds>;
}
export default MultiscaleSpatialImage;
export declare const getVoxelCount: (image: MultiscaleSpatialImage, scale: number, bounds?: Bounds | undefined) => Promise<number>;
export declare const getBytes: ({ imageType: { componentType, components } }: MultiscaleSpatialImage, voxelCount: number) => number;
export type ImageWithMeta = Awaited<ReturnType<MultiscaleSpatialImage['buildImage']>>;
export type BuiltImage = Awaited<ReturnType<MultiscaleSpatialImage['getImage']>> & {
    imageType: ImageType;
};
//# sourceMappingURL=MultiscaleSpatialImage.d.ts.map