/**
 * Zod schemas started with NGFF image.schema file https://github.com/ome/ngff/tree/main/0.4/schemas
 * and run through converter here: https://stefanterdell.github.io/json-schema-to-zod-react/
 * then manually edited.
 *
 */
import { z } from 'zod';
declare const dimension: z.ZodEnum<["x", "y", "z", "c", "t"]>;
export type Dimension = z.infer<typeof dimension>;
declare const axis: z.ZodObject<{
    name: z.ZodEnum<["x", "y", "z", "c", "t"]>;
    type: z.ZodOptional<z.ZodEnum<["channel", "time", "space"]>>;
}, "strip", z.ZodTypeAny, {
    name: "x" | "y" | "z" | "c" | "t";
    type?: "channel" | "time" | "space" | undefined;
}, {
    name: "x" | "y" | "z" | "c" | "t";
    type?: "channel" | "time" | "space" | undefined;
}>;
export type Axis = z.infer<typeof axis>;
declare const transform: z.ZodUnion<[z.ZodObject<{
    type: z.ZodEnum<["scale"]>;
    scale: z.ZodArray<z.ZodNumber, "many">;
}, "strip", z.ZodTypeAny, {
    type: "scale";
    scale: number[];
}, {
    type: "scale";
    scale: number[];
}>, z.ZodObject<{
    type: z.ZodEnum<["translation"]>;
    translation: z.ZodArray<z.ZodNumber, "many">;
}, "strip", z.ZodTypeAny, {
    type: "translation";
    translation: number[];
}, {
    type: "translation";
    translation: number[];
}>]>;
export type Transform = z.infer<typeof transform>;
export declare const IMAGE_VERSION_DEFAULT = "0.4";
export declare const image: {
    '0.4': z.ZodObject<{
        multiscales: z.ZodArray<z.ZodObject<{
            direction: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodNumber, "many">, "many">>;
            ranges: z.ZodOptional<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">>;
            name: z.ZodOptional<z.ZodString>;
            datasets: z.ZodArray<z.ZodObject<{
                path: z.ZodString;
                coordinateTransformations: z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    type: z.ZodEnum<["scale"]>;
                    scale: z.ZodArray<z.ZodNumber, "many">;
                }, "strip", z.ZodTypeAny, {
                    type: "scale";
                    scale: number[];
                }, {
                    type: "scale";
                    scale: number[];
                }>, z.ZodObject<{
                    type: z.ZodEnum<["translation"]>;
                    translation: z.ZodArray<z.ZodNumber, "many">;
                }, "strip", z.ZodTypeAny, {
                    type: "translation";
                    translation: number[];
                }, {
                    type: "translation";
                    translation: number[];
                }>]>, "many">;
            }, "strip", z.ZodTypeAny, {
                path: string;
                coordinateTransformations: ({
                    type: "scale";
                    scale: number[];
                } | {
                    type: "translation";
                    translation: number[];
                })[];
            }, {
                path: string;
                coordinateTransformations: ({
                    type: "scale";
                    scale: number[];
                } | {
                    type: "translation";
                    translation: number[];
                })[];
            }>, "many">;
            version: z.ZodOptional<z.ZodEnum<["0.4"]>>;
            axes: z.ZodArray<z.ZodObject<{
                name: z.ZodEnum<["x", "y", "z", "c", "t"]>;
                type: z.ZodOptional<z.ZodEnum<["channel", "time", "space"]>>;
            }, "strip", z.ZodTypeAny, {
                name: "x" | "y" | "z" | "c" | "t";
                type?: "channel" | "time" | "space" | undefined;
            }, {
                name: "x" | "y" | "z" | "c" | "t";
                type?: "channel" | "time" | "space" | undefined;
            }>, "many">;
            coordinateTransformations: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                type: z.ZodEnum<["scale"]>;
                scale: z.ZodArray<z.ZodNumber, "many">;
            }, "strip", z.ZodTypeAny, {
                type: "scale";
                scale: number[];
            }, {
                type: "scale";
                scale: number[];
            }>, z.ZodObject<{
                type: z.ZodEnum<["translation"]>;
                translation: z.ZodArray<z.ZodNumber, "many">;
            }, "strip", z.ZodTypeAny, {
                type: "translation";
                translation: number[];
            }, {
                type: "translation";
                translation: number[];
            }>]>, "many">>;
        }, "strip", z.ZodTypeAny, {
            datasets: {
                path: string;
                coordinateTransformations: ({
                    type: "scale";
                    scale: number[];
                } | {
                    type: "translation";
                    translation: number[];
                })[];
            }[];
            axes: {
                name: "x" | "y" | "z" | "c" | "t";
                type?: "channel" | "time" | "space" | undefined;
            }[];
            direction?: number[][] | undefined;
            ranges?: [number, number][] | undefined;
            name?: string | undefined;
            coordinateTransformations?: ({
                type: "scale";
                scale: number[];
            } | {
                type: "translation";
                translation: number[];
            })[] | undefined;
            version?: "0.4" | undefined;
        }, {
            datasets: {
                path: string;
                coordinateTransformations: ({
                    type: "scale";
                    scale: number[];
                } | {
                    type: "translation";
                    translation: number[];
                })[];
            }[];
            axes: {
                name: "x" | "y" | "z" | "c" | "t";
                type?: "channel" | "time" | "space" | undefined;
            }[];
            direction?: number[][] | undefined;
            ranges?: [number, number][] | undefined;
            name?: string | undefined;
            coordinateTransformations?: ({
                type: "scale";
                scale: number[];
            } | {
                type: "translation";
                translation: number[];
            })[] | undefined;
            version?: "0.4" | undefined;
        }>, "many">;
        omero: z.ZodOptional<z.ZodObject<{
            channels: z.ZodArray<z.ZodObject<{
                window: z.ZodObject<{
                    end: z.ZodNumber;
                    max: z.ZodOptional<z.ZodNumber>;
                    min: z.ZodOptional<z.ZodNumber>;
                    start: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                }, {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                }>;
                label: z.ZodOptional<z.ZodString>;
                family: z.ZodOptional<z.ZodString>;
                color: z.ZodString;
                active: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }, {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            channels: {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }[];
        }, {
            channels: {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }[];
        }>>;
    }, "strip", z.ZodTypeAny, {
        multiscales: {
            datasets: {
                path: string;
                coordinateTransformations: ({
                    type: "scale";
                    scale: number[];
                } | {
                    type: "translation";
                    translation: number[];
                })[];
            }[];
            axes: {
                name: "x" | "y" | "z" | "c" | "t";
                type?: "channel" | "time" | "space" | undefined;
            }[];
            direction?: number[][] | undefined;
            ranges?: [number, number][] | undefined;
            name?: string | undefined;
            coordinateTransformations?: ({
                type: "scale";
                scale: number[];
            } | {
                type: "translation";
                translation: number[];
            })[] | undefined;
            version?: "0.4" | undefined;
        }[];
        omero?: {
            channels: {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }[];
        } | undefined;
    }, {
        multiscales: {
            datasets: {
                path: string;
                coordinateTransformations: ({
                    type: "scale";
                    scale: number[];
                } | {
                    type: "translation";
                    translation: number[];
                })[];
            }[];
            axes: {
                name: "x" | "y" | "z" | "c" | "t";
                type?: "channel" | "time" | "space" | undefined;
            }[];
            direction?: number[][] | undefined;
            ranges?: [number, number][] | undefined;
            name?: string | undefined;
            coordinateTransformations?: ({
                type: "scale";
                scale: number[];
            } | {
                type: "translation";
                translation: number[];
            })[] | undefined;
            version?: "0.4" | undefined;
        }[];
        omero?: {
            channels: {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }[];
        } | undefined;
    }>;
    '0.1': z.ZodObject<{
        multiscales: z.ZodArray<z.ZodObject<{
            direction: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodNumber, "many">, "many">>;
            ranges: z.ZodOptional<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">>;
            name: z.ZodOptional<z.ZodString>;
            datasets: z.ZodArray<z.ZodObject<{
                path: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                path: string;
            }, {
                path: string;
            }>, "many">;
            version: z.ZodOptional<z.ZodEnum<["0.1"]>>;
            metadata: z.ZodOptional<z.ZodObject<{
                method: z.ZodOptional<z.ZodString>;
                version: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                version?: string | undefined;
                method?: string | undefined;
            }, {
                version?: string | undefined;
                method?: string | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            datasets: {
                path: string;
            }[];
            direction?: number[][] | undefined;
            ranges?: [number, number][] | undefined;
            name?: string | undefined;
            version?: "0.1" | undefined;
            metadata?: {
                version?: string | undefined;
                method?: string | undefined;
            } | undefined;
        }, {
            datasets: {
                path: string;
            }[];
            direction?: number[][] | undefined;
            ranges?: [number, number][] | undefined;
            name?: string | undefined;
            version?: "0.1" | undefined;
            metadata?: {
                version?: string | undefined;
                method?: string | undefined;
            } | undefined;
        }>, "many">;
        omero: z.ZodOptional<z.ZodObject<{
            channels: z.ZodArray<z.ZodObject<{
                window: z.ZodObject<{
                    end: z.ZodNumber;
                    max: z.ZodOptional<z.ZodNumber>;
                    min: z.ZodOptional<z.ZodNumber>;
                    start: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                }, {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                }>;
                label: z.ZodOptional<z.ZodString>;
                family: z.ZodOptional<z.ZodString>;
                color: z.ZodString;
                active: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }, {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            channels: {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }[];
        }, {
            channels: {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }[];
        }>>;
    }, "strip", z.ZodTypeAny, {
        multiscales: {
            datasets: {
                path: string;
            }[];
            direction?: number[][] | undefined;
            ranges?: [number, number][] | undefined;
            name?: string | undefined;
            version?: "0.1" | undefined;
            metadata?: {
                version?: string | undefined;
                method?: string | undefined;
            } | undefined;
        }[];
        omero?: {
            channels: {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }[];
        } | undefined;
    }, {
        multiscales: {
            datasets: {
                path: string;
            }[];
            direction?: number[][] | undefined;
            ranges?: [number, number][] | undefined;
            name?: string | undefined;
            version?: "0.1" | undefined;
            metadata?: {
                version?: string | undefined;
                method?: string | undefined;
            } | undefined;
        }[];
        omero?: {
            channels: {
                window: {
                    start: number;
                    end: number;
                    min?: number | undefined;
                    max?: number | undefined;
                };
                color: string;
                label?: string | undefined;
                family?: string | undefined;
                active?: boolean | undefined;
            }[];
        } | undefined;
    }>;
};
type Schema = z.infer<(typeof image)['0.1'] | (typeof image)['0.4']>;
export type NgffImage = Schema['multiscales'][number];
export type Dataset = NgffImage['datasets'][number];
export declare const datasetZattrs: z.ZodObject<{
    direction: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodNumber, "many">, "many">>;
    ranges: z.ZodOptional<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">>;
    _ARRAY_DIMENSIONS: z.ZodOptional<z.ZodArray<z.ZodEnum<["x", "y", "z", "c", "t"]>, "many">>;
}, "strip", z.ZodTypeAny, {
    direction?: number[][] | undefined;
    ranges?: [number, number][] | undefined;
    _ARRAY_DIMENSIONS?: ("x" | "y" | "z" | "c" | "t")[] | undefined;
}, {
    direction?: number[][] | undefined;
    ranges?: [number, number][] | undefined;
    _ARRAY_DIMENSIONS?: ("x" | "y" | "z" | "c" | "t")[] | undefined;
}>;
export declare const zArray: z.ZodObject<{
    shape: z.ZodArray<z.ZodNumber, "many">;
    chunks: z.ZodArray<z.ZodNumber, "many">;
    dtype: z.ZodString;
    compressor: z.ZodObject<{
        cname: z.ZodEnum<["raw", "zlib", "blosc", "bzip2", "lz4", "lz4hc", "zstd"]>;
        blocksize: z.ZodOptional<z.ZodNumber>;
        clevel: z.ZodOptional<z.ZodNumber>;
        shuffle: z.ZodOptional<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        cname: "raw" | "zlib" | "blosc" | "bzip2" | "lz4" | "lz4hc" | "zstd";
        blocksize?: number | undefined;
        clevel?: number | undefined;
        shuffle?: number | undefined;
    }, {
        cname: "raw" | "zlib" | "blosc" | "bzip2" | "lz4" | "lz4hc" | "zstd";
        blocksize?: number | undefined;
        clevel?: number | undefined;
        shuffle?: number | undefined;
    }>;
    dimension_separator: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    chunks: number[];
    shape: number[];
    dtype: string;
    compressor: {
        cname: "raw" | "zlib" | "blosc" | "bzip2" | "lz4" | "lz4hc" | "zstd";
        blocksize?: number | undefined;
        clevel?: number | undefined;
        shuffle?: number | undefined;
    };
    dimension_separator?: string | undefined;
}, {
    chunks: number[];
    shape: number[];
    dtype: string;
    compressor: {
        cname: "raw" | "zlib" | "blosc" | "bzip2" | "lz4" | "lz4hc" | "zstd";
        blocksize?: number | undefined;
        clevel?: number | undefined;
        shuffle?: number | undefined;
    };
    dimension_separator?: string | undefined;
}>;
export type ZArray = z.infer<typeof zArray>;
export {};
//# sourceMappingURL=ngff-validator.d.ts.map