import { ReadonlyMat4 } from 'gl-matrix';
import { TypedArray } from 'itk-wasm';
export type ValueOf<T> = T[keyof T];
export type Awaitable<T> = Promise<T> | T;
export type Extent = [number, number, number, number, number, number];
export type Range = [number, number];
export type ReadonlyRange = readonly [number, number];
export type Ranges = Array<ReadonlyRange>;
export type Vector3 = [number, number, number];
export type Dimension = 'x' | 'y' | 'z' | 'c' | 't';
export type DimensionToRange = Map<Dimension, Range>;
export type DimensionBounds = DimensionToRange;
export type ReadOnlyDimensionBounds = ReadonlyMap<Dimension, ReadonlyRange>;
export type Direction = ReadonlyArray<ReadonlyArray<number>>;
type Constructor<T> = Function & {
    prototype: T;
};
export type TypedArrayConstructor = Constructor<TypedArray>;
export type SpatialDimensions = ['x'] | ['x', 'y'] | ['x', 'y', 'z'];
export type ChunkParameter = Map<Dimension, number>;
type LazyCoords = {
    get: (dim: Dimension) => Awaitable<Float32Array | undefined>;
    has: (dim: Dimension) => boolean;
};
export type ScaleInfo = {
    dims: ReadonlyArray<Dimension>;
    coords: LazyCoords;
    origin?: Array<number>;
    spacing?: Array<number>;
    direction?: Direction;
    chunkCount: ChunkParameter;
    chunkSize: ChunkParameter;
    arrayShape: ChunkParameter;
    ranges?: Ranges;
    name?: string;
    indexToWorld?: ReadonlyMat4;
    pixelArrayMetadata?: {
        dtype?: string;
        dimension_separator?: string;
    };
    pixelArrayPath?: string;
};
export {};
//# sourceMappingURL=types.d.ts.map